@@ -7,7 +7,7 @@
 # *
 # * This program is free software; you can redistribute it and/or modify
 # * it under the terms of the GNU General Public License as published by
-# * the Free Software Foundation; either version 2 of the License, or
+# * the Free Software Foundation; either version 3 of the License, or
 # * (at your option) any later version.
 # *
 # * This program is distributed in the hope that it will be useful,
@@ -40,9 +40,9 @@ from pyworkflow.object import (OrderedObject, Float, Integer, String,
 from pwem.constants import (NO_INDEX, ALIGN_NONE, ALIGN_2D, ALIGN_3D,
                             ALIGN_PROJ, ALIGNMENTS)
 
-
 class EMObject(OrderedObject):
     """Base object for all EM classes"""
+
     def __init__(self, **kwargs):
         OrderedObject.__init__(self, **kwargs)
 
@@ -56,6 +56,7 @@ class EMObject(OrderedObject):
 
 class Acquisition(EMObject):
     """Acquisition information"""
+
     def __init__(self, **kwargs):
         EMObject.__init__(self, **kwargs)
         self._magnification = Float(kwargs.get('magnification', None))
@@ -141,13 +142,13 @@ class CTFModel(EMObject):
 
         ctfStr = "defU={}, defV={}, ast={}, " \
                  "psh={}, res={}, fit={}".format(
-                  strEx(self._defocusU.get()),
-                  strEx(self._defocusV.get()),
-                  strEx(self._defocusAngle.get()),
-                  strEx(self.getPhaseShift()),
-                  strEx(self._resolution.get()),
-                  strEx(self._fitQuality.get())
-                  )
+            strEx(self._defocusU.get()),
+            strEx(self._defocusV.get()),
+            strEx(self._defocusAngle.get()),
+            strEx(self.getPhaseShift()),
+            strEx(self._resolution.get()),
+            strEx(self._fitQuality.get())
+        )
 
         return ctfStr
 
@@ -201,8 +202,8 @@ class CTFModel(EMObject):
 
     def copyInfo(self, other):
         self.copyAttributes(other, '_defocusU', '_defocusV', '_defocusAngle',
-                                   '_defocusRatio', '_psdFile', '_micFile',
-                                   '_resolution', '_fitQuality')
+                            '_defocusRatio', '_psdFile', '_micFile',
+                            '_resolution', '_fitQuality')
         if other.hasPhaseShift():
             self.setPhaseShift(other.getPhaseShift())
 
@@ -251,7 +252,7 @@ class CTFModel(EMObject):
             self._defocusAngle.sum(180.)
         # At this point defocusU is always greater than defocusV
         # following the EMX standard
-        self._defocusRatio.set(self.getDefocusU()/self.getDefocusV())
+        self._defocusRatio.set(self.getDefocusU() / self.getDefocusV())
 
     def equalAttributes(self, other, ignore=[], verbose=False):
         """ Override default behaviour to compare two
@@ -265,6 +266,7 @@ class CTFModel(EMObject):
 
 class DefocusGroup(EMObject):
     """ Groups CTFs by defocus"""
+
     def __init__(self, **kwargs):
         EMObject.__init__(self, **kwargs)
         self._defocusMin = Float()
@@ -302,6 +304,7 @@ class DefocusGroup(EMObject):
 
 class SetOfDefocusGroups:
     """ Store a set of several defocus groups."""
+
     def __init__(self, inputSet,
                  groupRange=1000,
                  groupMinSize=1,
@@ -372,6 +375,7 @@ class ImageDim(CsvList):
     """ Just a wrapper to a CsvList to store image dimensions
     as X, Y and Z.
     """
+
     def __init__(self, x=None, y=None, z=None):
         CsvList.__init__(self, pType=int)
         if x is not None and y is not None:
@@ -401,6 +405,7 @@ class ImageDim(CsvList):
 
 class Image(EMObject):
     """Represents an EM Image object"""
+
     def __init__(self, location=None, **kwargs):
         """
          Params:
@@ -610,6 +615,7 @@ class Image(EMObject):
 
 class Micrograph(Image):
     """ Represents an EM Micrograph object """
+
     def __init__(self, location=None, **kwargs):
         Image.__init__(self, location, **kwargs)
         self._micName = String()
@@ -631,10 +637,11 @@ class Micrograph(Image):
 
 class Particle(Image):
     """ Represents an EM Particle object """
+
     def __init__(self, location=None, **kwargs):
         Image.__init__(self, location, **kwargs)
         # This may be redundant, but make the Particle
-        # object more indenpent for tracking coordinates
+        # object more independent for tracking coordinates
         self._coordinate = None
         self._micId = Integer()
         self._classId = Integer()
@@ -685,6 +692,7 @@ class Mask(Particle):
 
 class Volume(Image):
     """ Represents an EM Volume object """
+
     def __init__(self, location=None, **kwargs):
         Image.__init__(self, location, **kwargs)
         self._classId = Integer()
@@ -732,6 +740,7 @@ class VolumeMask(Volume):
 
 class EMFile(EMObject):
     """ Class to link usually to text files. """
+
     def __init__(self, filename=None, **kwargs):
         EMObject.__init__(self, **kwargs)
         self._filename = String(filename)
@@ -1072,7 +1081,7 @@ class SetOfImages(EMSet):
         for i, img in enumerate(self.iterItems(orderBy=orderBy,
                                                direction=direction)):
             transform = img.getTransform() if applyTransform else None
-            ih.convert(img, (i+1, fnStack), transform=transform)
+            ih.convert(img, (i + 1, fnStack), transform=transform)
 
     # TODO: Check whether this function can be used.
     # for example: protocol_apply_mask
@@ -1082,7 +1091,7 @@ class SetOfImages(EMSet):
 
         _, _, _, ndim = ImageHandler().getDimensions(fnStack)
         img = self.ITEM_TYPE()
-        for i in range(1, ndim+1):
+        for i in range(1, ndim + 1):
             img.setObjId(None)
             img.setLocation(i, fnStack)
             if postprocessImage is not None:
@@ -1240,6 +1249,7 @@ class SetOfParticles(SetOfImages):
 class SetOfAverages(SetOfParticles):
     """Represents a set of Averages.
     It is a SetOfParticles but it is useful to differentiate outputs."""
+
     def __init__(self, **kwargs):
         SetOfParticles.__init__(self, **kwargs)
 
@@ -1320,6 +1330,7 @@ class SetOfAtomStructs(EMSet):
 
 class SetOfPDBs(SetOfAtomStructs):
     """ Set containing PDB items. """
+
     def __init__(self):
         SetOfAtomStructs.__init__(self)
         print("SetOfPDBs class has been renamed to SetOfAtomStructs. "
@@ -1334,6 +1345,7 @@ class SetOfSequences(EMSet):
 class Coordinate(EMObject):
     """This class holds the (x,y) position and other information
     associated with a coordinate"""
+
     def __init__(self, **kwargs):
         EMObject.__init__(self, **kwargs)
         self._micrographPointer = Pointer(objDoStore=False)
@@ -1482,7 +1494,7 @@ class SetOfCoordinates(EMSet):
             self._micrographsPointer.copy(micrographs)
         else:
             self._micrographsPointer.set(micrographs)
-        
+
     def getFiles(self):
         filePaths = set()
         filePaths.add(self.getFileName())
@@ -1515,7 +1527,7 @@ class Matrix(Scalar):
         self._matrix = np.eye(4)
 
     def _convertValue(self, value):
-        """Value should be a str with comman separated values
+        """Value should be a str with comma separated values
         or a list.
         """
         self._matrix = np.array(json.loads(value))
@@ -1551,6 +1563,7 @@ class Transform(EMObject):
     that can be applied to 2D/3D objects like images and volumes.
     It should contain information about euler angles, translation(or shift)
     and mirroring.
+    Shifts are stored in pixels as treated in extract coordinates, or assign angles,...
     """
 
     def __init__(self, matrix=None, **kwargs):
@@ -1577,15 +1590,21 @@ class Transform(EMObject):
         m *= factor
         m[3, 3] = 1.
 
-    def scaleShifts(self, factor, shiftsAppliedBefore=False):
+    def scaleShifts(self, factor):
+        # By default Scipion uses a coordinate system associated with the volume rather than the projection
         m = self.getMatrix()
-        if shiftsAppliedBefore:
-            m[0, 3] -= int(m[0,3])  # Decimal part of X translation
-            m[1, 3] -= int(m[1,3])  # Decimal part of Y translation
         m[0, 3] *= factor
         m[1, 3] *= factor
         m[2, 3] *= factor
 
+    def invert(self):
+        # Local import to avoid loop pwem --> data --> convert --> Plugin (at pwem)
+        from pwem.convert.transformations import inverse_matrix
+
+        self._matrix.setMatrix(inverse_matrix(self._matrix.getMatrix()))
+
+        return self._matrix
+
     def getShifts(self):
         m = self.getMatrix()
         return m[0, 3], m[1, 3], m[2, 3]
@@ -1611,6 +1630,7 @@ class Class2D(SetOfParticles):
     (some kind of average particle from the particles assigned
     to the class)
     """
+
     def copyInfo(self, other):
         """ Copy basic information (id and other properties) but
         not _mapperPath or _size from other set of micrographs to current one.
@@ -1654,6 +1674,7 @@ class ClassVol(SetOfVolumes):
     """ Represent a Class that groups Volume objects.
     Usually the representative of the class is another Volume.
     """
+
     def close(self):
         # Do nothing on close, since the db will be closed by SetOfClasses
         pass
@@ -1674,7 +1695,6 @@ class SetOfClasses(EMSet):
         """ Copy basic information from other set of classes to current one"""
         self.copyAttributes(other, '_representatives', '_imagesPointer')
 
-
     def iterClassItems(self, iterDisabled=False):
         """ Iterate over the images of a class.
         Params:
@@ -1852,7 +1872,7 @@ class SetOfClasses2D(SetOfClasses):
 
         for i, class2D in enumerate(self):
             img = class2D.getRepresentative()
-            ih.convert(img, (i+1, fnStack))
+            ih.convert(img, (i + 1, fnStack))
 
 
 class SetOfClasses3D(SetOfClasses):
@@ -1872,6 +1892,7 @@ class SetOfClassesVol(SetOfClasses3D):
 
 class NormalMode(EMObject):
     """ Store normal mode information. """
+
     def __init__(self, **kwargs):
         EMObject.__init__(self, **kwargs)
         self._modeFile = String(kwargs.get('modeFile', None))
@@ -1921,6 +1942,7 @@ class FramesRange(CsvList):
     """ Store first and last frames in a movie. The last element will be
      the index in the stack of the first frame.
     """
+
     def __init__(self, firstFrame=1, lastFrame=0, firstFrameIndex=1):
         """
         Frames numbering always refer to the initial movies imported into
@@ -1965,6 +1987,7 @@ class FramesRange(CsvList):
 class Movie(Micrograph):
     """ Represent a set of frames of micrographs.
     """
+
     def __init__(self, location=None, **kwargs):
         Micrograph.__init__(self, location, **kwargs)
 
@@ -2027,6 +2050,7 @@ class MovieAlignment(EMObject):
     """ Store the alignment between the different Movie frames.
     Also store the first and last frames used for alignment.
     """
+
     def __init__(self, first=-1, last=-1, **kwargs):
         EMObject.__init__(self, **kwargs)
         self._first = Integer(first)
@@ -2149,6 +2173,7 @@ class SetOfMovieParticles(SetOfParticles):
 
 class FSC(EMObject):
     """Store a Fourier Shell Correlation"""
+
     def __init__(self, **kwargs):
         EMObject.__init__(self, **kwargs)
         self._x = CsvList(pType=float)
